@@ -103,6 +103,7 @@
 #include "downloader.h"
 #include "sqlrefpolicy.h"
 #include "semodule_dontaudit.h"
+#include "segatex_getseuserbyname.h"
 
  MainWindow::MainWindow()
 {
@@ -151,6 +152,7 @@
 	downloader_o = 0;
 	sqlrefpolicy_o = 0;
 	semodule_dontaudit_o = 0;
+	segatex_getseuserbyname_o = 0;
 
 	//semodule_dontaudit_o = new SemoduleDontaudit(this);
 	//semodule_dontaudit_o->semodule_dontaudit_base_process();
@@ -161,7 +163,7 @@
 	createStatusBar();
 	updateMenus();
 	readSettings();
-	setWindowTitle(tr("segatex-7.775"));
+	setWindowTitle(tr("segatex-7.780"));
 	QPixmap myIcon1 = QPixmap(":/images/icon.png");
 	this->setIcon(myIcon1);
 	//for test
@@ -202,6 +204,8 @@ void MainWindow::createMenus()
 	policyMenu->addAction(enforcingAct);
 	policyMenu->addAction(check_selinuxAct);
 	policyMenu->addAction(default_policyAct);
+	policyMenu->addAction(selinux_pathAct);
+	policyMenu->addAction(segatex_getseuserbynameAct);
 
 	manageMenu = menuBar()->addMenu(tr("&Modules"));
 	manageMenu->addAction(semodule_core_processAct);
@@ -331,45 +335,7 @@ void MainWindow::createActions()
 	separatorAct = new QAction(this);
 	separatorAct->setSeparator(true);
 
-	aboutAct = new QAction(tr("&About"), this);
-	aboutAct->setStatusTip(tr("Show the application's About box"));
-	connect(aboutAct, SIGNAL(triggered()), this, SLOT(about()));
-	connect(newAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	aboutQtAct = new QAction(tr("About &Qt"), this);
-	aboutQtAct->setStatusTip(tr("Show the Qt library's About box"));
-	connect(aboutQtAct, SIGNAL(triggered()), qApp, SLOT(aboutQt()));
-	connect(newAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	breakteAct = new QAction(tr("Breake &te"), this);
-	breakteAct->setStatusTip(tr("Break .te files"));
-	connect(breakteAct, SIGNAL(activated()), this, SLOT(break_te()));
-	connect(breakteAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	breakifAct = new QAction(tr("Breake &if"), this);
-	breakifAct->setStatusTip(tr("Break .if files"));
-	connect(breakifAct, SIGNAL(activated()), this, SLOT(break_if()));
-	connect(breakifAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	howtouseAct = new QAction(tr("&How to use"), this);
-	howtouseAct->setStatusTip(tr("Show the application's How to use box"));
-	connect(howtouseAct, SIGNAL(activated()), this, SLOT(howtouse()));
-	connect(howtouseAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	enforcingAct = new QAction(tr("Change SELinux &state"), this);
-	enforcingAct->setStatusTip(tr("Change Enforcing / Permissive"));
-	connect(enforcingAct, SIGNAL(activated()), this, SLOT(enforcing()));
-	connect(enforcingAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	check_selinuxAct = new QAction(tr("&Check SELinux state"), this);
-	check_selinuxAct->setStatusTip(tr("Check SELinux State at present"));
-	connect(check_selinuxAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	default_policyAct = new QAction(tr("&Default SELinux policy type"), this);
-	default_policyAct->setStatusTip(tr("Check SELinux default policy type"));
-	connect(default_policyAct, SIGNAL(activated()), segatex_state, SLOT(default_policy_type()));
-	connect(default_policyAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
+/////////////////////// Policy ////////////////////////////////////////
 	sqlrefpolicyAct = new QAction(tr("&Refpolicy Analizer"), this);
 	sqlrefpolicyAct->setStatusTip(tr("Analyze refpolicy"));
 	connect(sqlrefpolicyAct, SIGNAL(activated()), this, SLOT(sqlrefpolicy()));
@@ -380,31 +346,65 @@ void MainWindow::createActions()
 	connect(selinuxYumAct, SIGNAL(activated()), this, SLOT(yum_selinux()));
 	connect(selinuxYumAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	selinuxYumProcessAct = new QAction(tr("&Yum install/update"), this);
-	selinuxYumProcessAct->setStatusTip(tr("Yum install/update SELinux related RPMs."));
-	connect(selinuxYumProcessAct, SIGNAL(activated()), this, SLOT(yum_selinux_process()));
-	connect(selinuxYumProcessAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+	check_selinuxAct = new QAction(tr("&Check SELinux state"), this);
+	check_selinuxAct->setStatusTip(tr("Check SELinux State at present"));
+	connect(check_selinuxAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
+	default_policyAct = new QAction(tr("&Default SELinux policy type"), this);
+	default_policyAct->setStatusTip(tr("Check SELinux default policy type"));
+	connect(default_policyAct, SIGNAL(activated()), segatex_state, SLOT(default_policy_type()));
+	connect(default_policyAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	enforcingAct = new QAction(tr("Change SELinux &state"), this);
+	enforcingAct->setStatusTip(tr("Change Enforcing / Permissive"));
+	connect(enforcingAct, SIGNAL(activated()), this, SLOT(enforcing()));
+	connect(enforcingAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	selinux_pathAct = new QAction(tr("Check SELinux &path"), this);
+	selinux_pathAct->setStatusTip(tr("Check SELinux path"));
+	connect(selinux_pathAct, SIGNAL(activated()), segatex_state, SLOT(segatex_selinux_path()));
+	connect(selinux_pathAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	segatex_getseuserbynameAct = new QAction(tr("Get se&user and level from linuxuser"), this);
+	segatex_getseuserbynameAct->setStatusTip(tr("Get seuser and level from linuxuser"));
+	connect(segatex_getseuserbynameAct, SIGNAL(activated()), this, SLOT(segatex_getseuserbyname()));
+	connect(segatex_getseuserbynameAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+/////////////////////// Audit ////////////////////////////////////////
 	semodule_dontauditAct = new QAction(tr("dont&audit"), this);
-	semodule_dontauditAct->setStatusTip(tr("manage don't audit"));
+	semodule_dontauditAct->setStatusTip(tr("manage dontaudit"));
 	connect(semodule_dontauditAct, SIGNAL(activated()), this, SLOT(semodule_dontaudit()));
 	connect(semodule_dontauditAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	audit2allowAct = new QAction(tr("&Audit2allow"), this);
-	audit2allowAct->setStatusTip(tr("audit2allow"));
-	connect(audit2allowAct, SIGNAL(activated()), this, SLOT(audit2allow()));
-	connect(audit2allowAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
 	segatex_coreAct = new QAction(tr("Analize audit.&log"), this);
 	segatex_coreAct->setStatusTip(tr("Analize audit.log in many ways."));
 	connect(segatex_coreAct, SIGNAL(activated()), this, SLOT(segatex_core()));
 	connect(segatex_coreAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
+	audit2allowAct = new QAction(tr("Audi&t2allow"), this);
+	audit2allowAct->setStatusTip(tr("audit2allow"));
+	connect(audit2allowAct, SIGNAL(activated()), this, SLOT(audit2allow()));
+	connect(audit2allowAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	aureportAct = new QAction(tr("Au&report"), this);
+	aureportAct->setStatusTip(tr("Aureport"));
+	connect(aureportAct, SIGNAL(activated()), this, SLOT(aureport()));
+	connect(aureportAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	ausearchAct = new QAction(tr("Au&search"), this);
+	aureportAct->setStatusTip(tr("Ausearch"));
+	connect(ausearchAct, SIGNAL(activated()), this, SLOT(ausearch()));
+	connect(ausearchAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+////////////////////// Modules /////////////////////////////////////////
 	semodule_core_processAct = new QAction(tr("&Modules"), this);
 	semodule_core_processAct->setStatusTip(tr("Modules."));
 	connect(semodule_core_processAct, SIGNAL(activated()), this, SLOT(semodule_core_process()));
 	connect(semodule_core_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
+	policygeneration_processAct = new QAction(tr("Policy_&module "), this);
+	policygeneration_processAct->setStatusTip(tr("Generate policy_module."));
+	connect(policygeneration_processAct, SIGNAL(activated()), this, SLOT(policygeneration_process()));
+	connect(policygeneration_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+//////////////////////  Semanage /////////////////////////////////////////
 	semanage_core_processAct = new QAction(tr("&list objects"), this);
 	semanage_core_processAct->setStatusTip(tr("Semanage login -l user -l boolean -l port -l interface -l fcontext -l translation -l."));
 	connect(semanage_core_processAct, SIGNAL(activated()), this, SLOT(semanage_core_process()));
@@ -444,27 +444,17 @@ void MainWindow::createActions()
 	seinfoAct->setStatusTip(tr("Seinfo [options]"));
 	connect(seinfoAct, SIGNAL(activated()), this, SLOT(seinfo()));
 	connect(seinfoAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+/////////////////////// Relabel ////////////////////////////////////////////////
+	restoreconAct = new QAction(tr("&restorecon"), this);
+	restoreconAct->setStatusTip(tr("restorecon"));
+	connect(restoreconAct, SIGNAL(activated()), this, SLOT(restorecon()));
+	connect(restoreconAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	autorelabel_processAct = new QAction(tr("auto&relabel "), this);
+	autorelabel_processAct = new QAction(tr("autore&label "), this);
 	autorelabel_processAct->setStatusTip(tr("autorelabel the system."));
 	connect(autorelabel_processAct, SIGNAL(activated()), this, SLOT(autorelabel_process()));
 	connect(autorelabel_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	policygeneration_processAct = new QAction(tr("Policy_&module "), this);
-	policygeneration_processAct->setStatusTip(tr("Generate policy_module."));
-	connect(policygeneration_processAct, SIGNAL(activated()), this, SLOT(policygeneration_process()));
-	connect(policygeneration_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	aureportAct = new QAction(tr("&Aureport"), this);
-	aureportAct->setStatusTip(tr("Aureport"));
-	connect(aureportAct, SIGNAL(activated()), this, SLOT(aureport()));
-	connect(aureportAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	ausearchAct = new QAction(tr("&Ausearch"), this);
-	aureportAct->setStatusTip(tr("Ausearch"));
-	connect(ausearchAct, SIGNAL(activated()), this, SLOT(ausearch()));
-	connect(ausearchAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
+/////////////////////// Misc ///////////////////////////////////////////
 	useraddAct = new QAction(tr("&Useradd/delete"), this);
 	useraddAct->setStatusTip(tr("useradd/delete"));
 	connect(useraddAct, SIGNAL(activated()), this, SLOT(useradd()));
@@ -474,42 +464,42 @@ void MainWindow::createActions()
 	seeprocessAct->setStatusTip(tr("see process"));
 	connect(seeprocessAct, SIGNAL(activated()), this, SLOT(seeprocess()));
 	connect(seeprocessAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
-	restoreconAct = new QAction(tr("&restorecon"), this);
-	restoreconAct->setStatusTip(tr("restorecon"));
-	connect(restoreconAct, SIGNAL(activated()), this, SLOT(restorecon()));
-	connect(restoreconAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
-
+/////////////////////// Download ///////////////////////////////////////////
 	downloaderAct = new QAction(tr("&download Fedora"), this);
 	downloaderAct->setStatusTip(tr("download Fedora"));
 	connect(downloaderAct, SIGNAL(activated()), this, SLOT(downloader()));
 	connect(downloaderAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+/////////////////////// Break .te ///////////////////////////////////////////
+	breakteAct = new QAction(tr("Breake &te"), this);
+	breakteAct->setStatusTip(tr("Break .te files"));
+	connect(breakteAct, SIGNAL(activated()), this, SLOT(break_te()));
+	connect(breakteAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+/////////////////////// Break .if ///////////////////////////////////////////
+	breakifAct = new QAction(tr("Breake &if"), this);
+	breakifAct->setStatusTip(tr("Break .if files"));
+	connect(breakifAct, SIGNAL(activated()), this, SLOT(break_if()));
+	connect(breakifAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+/////////////////////// Help ////////////////////////////////////////
+	howtouseAct = new QAction(tr("&How to use"), this);
+	howtouseAct->setStatusTip(tr("Show the application's How to use box"));
+	connect(howtouseAct, SIGNAL(activated()), this, SLOT(howtouse()));
+	connect(howtouseAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	semodule_dontauditAct = new QAction(tr("dont&audit"), this);
-	semodule_dontauditAct->setStatusTip(tr("manage dontaudit"));
-	connect(semodule_dontauditAct, SIGNAL(activated()), this, SLOT(semodule_dontaudit()));
-	connect(semodule_dontauditAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+	aboutAct = new QAction(tr("&About"), this);
+	aboutAct->setStatusTip(tr("Show the application's About box"));
+	connect(aboutAct, SIGNAL(triggered()), this, SLOT(about()));
+	connect(newAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	aboutQtAct = new QAction(tr("About &Qt"), this);
+	aboutQtAct->setStatusTip(tr("Show the Qt library's About box"));
+	connect(aboutQtAct, SIGNAL(triggered()), qApp, SLOT(aboutQt()));
+	connect(newAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 }
 
 
 void MainWindow::updateSegatexStateIndicator()
 {
-	selinux_policy = segatex_state->loaded_policy();
-	enabled_or_not_str = segatex_state->is_selinux_enabled_segatex();
-	getenforce_str = segatex_state->getenforce_segatex();
-	if(enabled_or_not_str == "disabled")
-	{
-	selinux_policy = "SELinux is fully " + enabled_or_not_str + ".";
-	segatexStateLabel->setPaletteBackgroundColor(QColor(255, 122, 162));
-	}
-	else
-	{
-	selinux_policy = "SELinux is " + enabled_or_not_str + " and policy " + selinux_policy + " " + getenforce_str + " is in use.";
-		if(getenforce_str == "enforcing")
-			segatexStateLabel->setPaletteBackgroundColor(QColor(155, 155, 255));
-		if(getenforce_str == "permissive")
-			segatexStateLabel->setPaletteBackgroundColor(QColor(255, 251, 126));
-	}
+	selinux_policy = createStatusBar_pre();
 	segatexStateLabel->clear();
 	segatexStateLabel->setText(tr(selinux_policy));
 }
@@ -583,7 +573,7 @@ void MainWindow::open()
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-7.775</h2>"
+		tr("<h2>segatex-7.780</h2>"
 		"<p>Copyright &copy; 2007-2009"
 		"<p>Shintaro Fujiwara."
 		"<p>segatex is a SELinux tool"
@@ -659,22 +649,48 @@ MdiChild *MainWindow::createMdiChild()
      editToolBar->addAction(copyAct);
      editToolBar->addAction(pasteAct);
  }
+ QString MainWindow::createStatusBar_pre()
+ {
+	selinux_policy = segatex_state->loaded_policy();
+	enabled_or_not_str = segatex_state->is_selinux_enabled_segatex();
+	getenforce_str = segatex_state->getenforce_segatex();
+	segatex_selinux_policy_root_str = segatex_state->segatex_selinux_policy_root();
+	segatex_security_policyvers_int = segatex_state->segatex_security_policyvers();
+	//segatex_security_policyvers_str = (QString)segatex_security_policyvers_int;
+	if(enabled_or_not_str == "disabled")
+	{
+		selinux_policy = "SELinux is fully " + enabled_or_not_str + ".";
+		segatexStateLabel->setPaletteBackgroundColor(QColor(255, 122, 162));
+	}
+	else
+	{
+		selinux_policy = "SELinux is " + enabled_or_not_str + " and policy " + selinux_policy + " " + getenforce_str + " is in use."
+		//+ " Policy root is " + segatex_selinux_policy_root_str + " and version is " + segatex_security_policyvers_str + ".";
+		+ " Policy root is " + segatex_selinux_policy_root_str;
+		/*
+		if(getenforce_str == "enforcing")
+			segatexStateLabel->setPaletteBackgroundColor(QColor(155, 155, 255));
+		if(getenforce_str == "permissive")
+			segatexStateLabel->setPaletteBackgroundColor(QColor(255, 251, 126));
+		*/
+	}
+	return selinux_policy;
+ }
  void MainWindow::createStatusBar()
  {
 	readyLabel = new QLabel(tr(" Ready"), this);
 
 	modLabel = new QLabel(tr(" MOD "), this);
 
-	//newly added
-	selinux_policy = segatex_state->loaded_policy();
-	enabled_or_not_str = segatex_state->is_selinux_enabled_segatex();
-	getenforce_str = segatex_state->getenforce_segatex();
-	if(enabled_or_not_str == "disabled")
-	selinux_policy = "SELinux is " + enabled_or_not_str + ".";
-	else
-	selinux_policy = "SELinux is " + enabled_or_not_str + " and policy " + selinux_policy + " is moving in " + getenforce_str + " mode.";
+	selinux_policy = createStatusBar_pre();
 	segatexStateLabel = new QLabel(tr(selinux_policy), this);
 	segatexStateLabel->setAlignment(Qt::AlignHCenter);
+	segatex_security_policyvers_int = segatex_state->segatex_security_policyvers();
+/////////////////////test////////////////
+	//segatex_security_policyvers_const_char = (const char *)segatex_security_policyvers_int;	
+	//segatexStateLabel2 = new QLabel(tr(segatex_security_policyvers_const_char), this);
+	//segatexStateLabel2->setAlignment(Qt::AlignHCenter);
+/////////////////////end test////////////////
 
 	modLabel->setAlignment(Qt::AlignHCenter);
 	modLabel->setMinimumSize(modLabel->sizeHint());
@@ -977,6 +993,15 @@ void MainWindow::sqlrefpolicy()
 	sqlrefpolicy_o->raise();
 	sqlrefpolicy_o->setActiveWindow();
 }
+void MainWindow::segatex_getseuserbyname()
+{
+	if(!segatex_getseuserbyname_o) {
+		segatex_getseuserbyname_o = new SegatexGetseuserbyname(this);
+	}
+	segatex_getseuserbyname_o->show();
+	segatex_getseuserbyname_o->raise();
+	segatex_getseuserbyname_o->setActiveWindow();
+}
 void MainWindow::howtouse()
 {
 	QMessageBox::about(this, tr("How to use"),
