@@ -78,6 +78,7 @@ class Restorecon;
 class Downloader;
 class Sqlrefpolicy;
 class SemoduleDontaudit;
+class SegatexGetseuserbyname;
 
 class MainWindow : public QMainWindow
 {
@@ -134,16 +135,19 @@ private slots:
 	void downloader();
 	void sqlrefpolicy();
 	void semodule_dontaudit();
+	void segatex_getseuserbyname();
 private:
 	void createActions();
 	void createMenus();
 	void createToolBars();
 	void createStatusBar();
+	QString createStatusBar_pre();
 	void readSettings();
 	void writeSettings();
 	QLabel *readyLabel;
 	QLabel *modLabel;
 	QLabel *segatexStateLabel;
+	QLabel *segatexStateLabel2;
 	QWorkspace *workspace;
 	MdiChild *activeMdiChild();
 	QMdiSubWindow *findMdiChild(const QString &fileName);
@@ -213,10 +217,16 @@ private:
 	QAction *downloaderAct;
 	QAction *sqlrefpolicyAct;
 	QAction *semodule_dontauditAct;
+	QAction *selinux_pathAct;
+	QAction *segatex_getseuserbynameAct;
 
 	QString selinux_policy;
 	QString enabled_or_not_str;
 	QString getenforce_str;
+	QString segatex_selinux_policy_root_str;
+	int segatex_security_policyvers_int;
+	QString segatex_security_policyvers_str;
+	const char *segatex_security_policyvers_const_char;
 
 	BreakTe *breakte;
 	BreakIf *breakif;
@@ -248,5 +258,6 @@ private:
 	Downloader *downloader_o;
 	Sqlrefpolicy *sqlrefpolicy_o;
 	SemoduleDontaudit *semodule_dontaudit_o;
+	SegatexGetseuserbyname *segatex_getseuserbyname_o;
 };
 #endif
