@@ -26,13 +26,15 @@
 #include "segatex_audit2allow.h" 
 
 class SegatexAudit2allow;
+class SegatexAudit2whyProcess;
 
 class SegatexAudit2allowProcess: public QDialog 
 {
 	Q_OBJECT
 public:
 	SegatexAudit2allowProcess(QWidget *parent = 0, const char *name = 0);
-	SegatexAudit2allow *selinux_audit2allow_common_obj;
+	//SegatexAudit2allow *segatex_audit2allow_common_obj;
+	SegatexAudit2whyProcess *segatex_audit2why_process;
 	int i;
 	QString outputfile_str_common;
 public slots:
@@ -49,8 +51,10 @@ public:
 private:
 	QPushButton *closeButton;
 	Q3TextEdit *textEdit1;
-	SegatexAudit2allow *selinux_audit2allow;
-	SegatexAudit2allowProcess *selinux_audit2allow_process;
+	//SegatexAudit2allow *selinux_audit2allow;
+	//SegatexAudit2allow *segatex_audit2allow;
+	//SegatexAudit2allowProcess *selinux_audit2allow_process;
+	//SegatexAudit2allowProcess *segatex_audit2allow_process;
 	int a,b,c,x,y,xx,yy,xxx,yyy,xxxx,yyyy;
 
         QDir dir;
