@@ -130,7 +130,7 @@ void SemanageCoreBooleanProcess::add_button_clicked_process(QString semanageEdit
 	if(permanentRadioButton->isChecked())
 		semanageEditLineEdit_str_pp = "setsebool -P " + semanageEditLineEdit_str + " " + semanageEditLineEdit2_str;
         #define PWD_BUF 8600
-        const char* make_module_file="/root/segatex/semanage/add_booleaned";
+        const char* make_module_file="/usr/share/segatex/semanage/add_booleaned";
         ofstream os_add;
         os_add.open(make_module_file);
         if(os_add){
@@ -160,7 +160,7 @@ void SemanageCoreBooleanProcess::add_button_clicked_process(QString semanageEdit
 void SemanageCoreBooleanProcess::semanage_core_base_boolean_process()
 {
         #define PWD_BUF 8600
-        const char* semanage_boolean_list_file="/root/segatex/semanage/1_boolean";
+        const char* semanage_boolean_list_file="/usr/share/segatex/semanage/1_boolean";
         ofstream os_test;
         os_test.open(semanage_boolean_list_file);
         if(os_test){
@@ -192,7 +192,7 @@ void SemanageCoreBooleanProcess::readFromOutputFile()
 {
 	/////////////////////////////////////////////////////////////
 	//path = "./";
-	path = "/root/segatex/semanage";
+	path = "/usr/share/segatex/semanage";
 	/////////////////////////////////////////////////////////////
 	forward_slash = "/";
 	dir.setPath(path);
