@@ -101,9 +101,9 @@ void SemanageCoreProcess::remove_button_clicked()
 /*
 void SemanageCoreProcess::make_button_clicked_process(QString semanageEditLineEdit_str)
 {
-	semanageEditLineEdit_str_pp = "cd /root/segatex;make -f /usr/share/selinux/devel/Makefile " + semanageEditLineEdit_str + ".pp";
+	semanageEditLineEdit_str_pp = "cd /usr/share/segatex;make -f /usr/share/selinux/devel/Makefile " + semanageEditLineEdit_str + ".pp";
         #define PWD_BUF 8600
-        const char* make_module_file="/root/segatex/make_module_file";
+        const char* make_module_file="/usr/share/segatex/make_module_file";
         ofstream os;
         os.open(make_module_file);
         if(os){
@@ -137,9 +137,9 @@ void SemanageCoreProcess::make_button_clicked_process(QString semanageEditLineEd
 /*
 void SemanageCoreProcess::install_button_clicked_process(QString semanageEditLineEdit_str)
 {
-	semanageEditLineEdit_str_pp = "cd /root/segatex;semodule -i " + semanageEditLineEdit_str + ".pp";
+	semanageEditLineEdit_str_pp = "cd /usr/share/segatex;semodule -i " + semanageEditLineEdit_str + ".pp";
         #define PWD_BUF 8600
-        const char* install_module_file="/root/segatex/install_module_file";
+        const char* install_module_file="/usr/share/segatex/install_module_file";
         ofstream os;
         os.open(install_module_file);
         if(os){
@@ -174,9 +174,9 @@ void SemanageCoreProcess::install_button_clicked_process(QString semanageEditLin
 /*
 void SemanageCoreProcess::update_button_clicked_process(QString semanageEditLineEdit_str)
 {
-	semanageEditLineEdit_str_pp = "cd /root/segatex;semodule -u " + semanageEditLineEdit_str + ".pp";
+	semanageEditLineEdit_str_pp = "cd /usr/share/segatex;semodule -u " + semanageEditLineEdit_str + ".pp";
         #define PWD_BUF 8600
-        const char* update_module_file="/root/segatex/update_module_file";
+        const char* update_module_file="/usr/share/segatex/update_module_file";
         ofstream os;
         os.open(update_module_file);
         if(os){
@@ -212,7 +212,7 @@ void SemanageCoreProcess::remove_button_clicked_process(QString moduleEditLineEd
 {
 	moduleEditLineEdit_str_pp = "semodule -r " + moduleEditLineEdit_str;
         #define PWD_BUF 8600
-        const char* remove_module_file="/root/segatex/remove_module_file";
+        const char* remove_module_file="/usr/share/segatex/remove_module_file";
         ofstream os;
         os.open(remove_module_file);
         if(os){
@@ -276,7 +276,7 @@ void SemanageCoreProcess::processExited()
 void SemanageCoreProcess::semanage_core_base_process()
 {
         #define PWD_BUF 8600
-        const char* semanage_login_list_file="/root/segatex/semanage/1_login_list";
+        const char* semanage_login_list_file="/usr/share/segatex/semanage/1_login_list";
         ofstream os;
         os.open(semanage_login_list_file);
         if(os){
@@ -300,7 +300,7 @@ void SemanageCoreProcess::semanage_core_base_process()
 	os.close();
 	//outputfile_str_common = "login_list";
 
-        const char* semanage_user_list_file="/root/segatex/semanage/2_user_list";
+        const char* semanage_user_list_file="/usr/share/segatex/semanage/2_user_list";
         ofstream os2;
         os2.open(semanage_user_list_file);
         if(os2){
@@ -323,7 +323,7 @@ void SemanageCoreProcess::semanage_core_base_process()
         }
 	os2.close();
 
-        const char* semanage_boolean_list_file="/root/segatex/semanage/3_boolean_list";
+        const char* semanage_boolean_list_file="/usr/share/segatex/semanage/3_boolean_list";
         ofstream os3;
         os3.open(semanage_boolean_list_file);
         if(os3){
@@ -346,7 +346,7 @@ void SemanageCoreProcess::semanage_core_base_process()
         }
 	os3.close();
 
-        const char* semanage_port_list_file="/root/segatex/semanage/4_port_list";
+        const char* semanage_port_list_file="/usr/share/segatex/semanage/4_port_list";
         ofstream os4;
         os4.open(semanage_port_list_file);
         if(os4){
@@ -369,7 +369,7 @@ void SemanageCoreProcess::semanage_core_base_process()
         }
 	os4.close();
 
-        const char* semanage_interface_list_file="/root/segatex/semanage/5_interface_list";
+        const char* semanage_interface_list_file="/usr/share/segatex/semanage/5_interface_list";
         ofstream os5;
         os5.open(semanage_interface_list_file);
         if(os5){
@@ -392,7 +392,7 @@ void SemanageCoreProcess::semanage_core_base_process()
         }
 	os5.close();
 
-        const char* semanage_fcontext_list_file="/root/segatex/semanage/6_fcontext_list";
+        const char* semanage_fcontext_list_file="/usr/share/segatex/semanage/6_fcontext_list";
         ofstream os6;
         os6.open(semanage_fcontext_list_file);
         if(os6){
@@ -415,7 +415,7 @@ void SemanageCoreProcess::semanage_core_base_process()
         }
 	os6.close();
 
-        const char* semanage_translation_list_file="/root/segatex/semanage/7_translation_list";
+        const char* semanage_translation_list_file="/usr/share/segatex/semanage/7_translation_list";
         ofstream os7;
         os7.open(semanage_translation_list_file);
         if(os7){
@@ -447,7 +447,7 @@ void SemanageCoreProcess::readFromOutputFile()
 {
 	/////////////////////////////////////////////////////////////
 	//path = "./";
-	path = "/root/segatex/semanage";
+	path = "/usr/share/segatex/semanage";
 	/////////////////////////////////////////////////////////////
 	forward_slash = "/";
 	dir.setPath(path);
